@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.010000';
+$MetaCPAN::Client::VERSION = '2.011000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -381,7 +381,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.010000
+version 2.011000
 
 =head1 SYNOPSIS
 
@@ -525,7 +525,7 @@ Returns a L<MetaCPAN::Client::Permission> object.
 
 =head2 reverse_dependencies
 
-    my $deps = $mcpan->reverse_dependencies('ElasticSearch');
+    my $deps = $mcpan->reverse_dependencies('Search::Elasticsearch');
 
 all L<MetaCPAN::Client::Release> objects of releases that are dependent
 on a given module, returned as L<MetaCPAN::Client::ResultSet>.
@@ -591,7 +591,7 @@ See SEARCH PARAMS.
 
 =head3 es_filter
 
-Pass a raw ElasticSearch filter structure to reduce the number
+Pass a raw Elasticsearch filter structure to reduce the number
 of elements returned by the query.
 
     my $some_releases = $mcpan->all('releases', { es_filter => {...} })
@@ -618,13 +618,13 @@ can be passed as a csv list or an array ref.
 
 =head2 _source
 
-Note: this param and its description are a bit too ElasticSearch specific.
+Note: this param and its description are a bit too Elasticsearch specific.
 just like 'es_filter' - use only if you know what you're dealing with.
 
-Some fields are not indexed in ElasticSearch but stored as part of
+Some fields are not indexed in Elasticsearch but stored as part of
 the entire document.
 
-These fields can still be read, but without the internal ElasticSearch
+These fields can still be read, but without the internal Elasticsearch
 optimizations and the server will interally read the whole document.
 
 Why do we even need those? because we don't index everything and some things
@@ -632,6 +632,29 @@ we can't to begin with (like non-leaf fields that hold a structure)
 
     my $module = $mcpan->all('releases', { _source => "stat" });
 
+=head2 scroller_time
+
+Note: please use with caution.
+
+This parameter will set the maximum lifetime of the Elasticsearch scroller on
+the server (default = '5m').  Normally you do not need to set this value (as
+tweaking this value can affect resources on the server).  In case you do, you
+probably need to check the efficiency of your code/queries.  (Feel free to
+reach out to us for assistance).
+
+    my $module = $mcpan->all('releases', { scroller_time => '3m' });
+
+=head2 scroller_size
+
+Note: please use with caution.
+
+This parameter will set the buffer size to be pulled from Elasticsearch
+when scrolling (default = 1000).
+This will affect query performance and memory usage, but you will still
+get an iterator back to fetch one object at a time.
+
+    my $module = $mcpan->all('releases', { scroller_size => 500 });
+
 =head1 SEARCH SPEC
 
 The hash-based search spec is common to many searches. It is quite
