@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '2.010000';
+$MetaCPAN::Client::Request::VERSION = '2.011000';
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
@@ -95,9 +95,13 @@ sub ssearch {
     my $args   = shift;
     my $params = shift;
 
+    my $time = delete $params->{'scroller_time'} || '5m';
+    my $size = delete $params->{'scroller_size'} || 1000;
+
     my $scroller = MetaCPAN::Client::Scroll->new(
         ua       => $self->ua,
-        size     => 1000,
+        size     => $size,
+        time     => $time,
         base_url => $self->base_url,
         type     => $type,
         body     => $self->_build_body($args, $params),
@@ -266,7 +270,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 2.010000
+version 2.011000
 
 =head1 ATTRIBUTES
 
@@ -311,7 +315,7 @@ Fetches a path from MetaCPAN (post or get), and returns the decoded result.
 
 =head2 ssearch
 
-Calls an ElasticSearch query and returns an L<MetaCPAN::Client::Scroll>
+Calls an Elasticsearch query and returns an L<MetaCPAN::Client::Scroll>
 scroller object.
 
 =head1 AUTHORS
