@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Scroll;
 # ABSTRACT: A MetaCPAN::Client scroller
-$MetaCPAN::Client::Scroll::VERSION = '2.010000';
+$MetaCPAN::Client::Scroll::VERSION = '2.011000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_hashref >;
@@ -154,13 +154,10 @@ sub _fetch_next {
 sub DEMOLISH {
     my $self = shift;
 
-    my $res = $self->ua->delete(
+    $self->ua->delete(
         sprintf( '%s/_search/scroll?scroll=%s', $self->base_url, $self->time ),
         { content => $self->_id }
     );
-
-    warn "failed to delete scroller"
-        unless $res->{status} == 200;
 }
 
 1;
@@ -177,7 +174,7 @@ MetaCPAN::Client::Scroll - A MetaCPAN::Client scroller
 
 =head1 VERSION
 
-version 2.010000
+version 2.011000
 
 =head1 METHODS
 
@@ -218,7 +215,7 @@ The total number of matches.
 
 =head2 type
 
-The ElasticSearch type to query.
+The Elasticsearch type to query.
 
 =head2 ua
 
